==> PDFlib-Lite-5.0.0-Unix-src.tar.gz: PDFlib-Lite-5.0.0-Unix-src/bind/pdflib/perl/businesscard.pl <==
#!/usr/bin/perl
# $Id: businesscard.pl,v 1.10 2003/03/19 15:34:36 tm Exp $
#
# PDFlib client: block processing example in C
#

use pdflib_pl 5.0;

$infile = "boilerplate.pdf";
# This is where font/image/PDF input files live. Adjust as necessary. 
$searchpath = "../data";

%data = (   "name"			=> "Victor Kraxi",
	    "business.title"		=> "Chief Paper Officer",
	    "business.address.line1" 	=> "17, Aviation Road",
	    "business.address.city"	=> "Paperfield",
	    "business.telephone.voice"	=> "phone +1 234 567-89",
	    "business.telephone.fax"	=> "fax +1 234 567-98",
	    "business.email"		=> "victor\@kraxi.com",
	    "business.homepage"		=> "www.kraxi.com"
	);

# create a new PDFlib object
$p = PDF_new();

eval {
    # open new PDF file
    if (PDF_open_file($p, "businesscard.pdf") == -1){
	print "Error: cannot open PDF file businesscard.pdf." ;
	exit;
    }

    PDF_set_parameter($p, "SearchPath", $searchpath);

    PDF_set_info($p, "Creator", "businesscard.pl");
    PDF_set_info($p, "Author", "Thomas Merz");
    PDF_set_info($p, "Title", "PDFlib block processing sample (Perl)");

    $blockcontainer = PDF_open_pdi($p, $infile, "", 0);
    if ($blockcontainer == -1){
	die "Couldn't open input file $infile.\n";
    }

    $page = PDF_open_pdi_page($p, $blockcontainer, 1, "");
    if ($page == -1){
	die "Couldn't open page 1 in $infile.\n";
    }

    PDF_begin_page($p, 20, 20);		# dummy page size

    # This will adjust the page size to the block container's size.
    PDF_fit_pdi_page($p, $page, 0, 0, "adjustpage");

    # Fill all text blocks with dynamic data
    foreach $elem(keys %data){
	if (PDF_fill_textblock($p, $page, $elem, $data{$elem},
            "embedding encoding winansi") == -1) {
	    printf("Warning: couldn't fill block '%s' in '%s'.\n", $elem,
		$data{$elem});
	}
    }

    PDF_end_page($p);			# close page
    PDF_close_pdi_page($p, $page);

    PDF_close($p);			# close PDF document
    PDF_close_pdi($p, $blockcontainer);
};
if ($@) {
    printf("businesscard: PDFlib Exception occurred:\n");
    printf(" $@\n");
    exit;
}
PDF_delete($p); 			# delete the PDFlib object

==> PDFlib-Lite-5.0.1-Unix-src.tar.gz: PDFlib-Lite-5.0.1-Unix-src/bind/pdflib/perl/businesscard.pl <==
#!/usr/bin/perl
# $Id: businesscard.pl,v 1.10.2.2 2003/05/06 16:21:17 rjs Exp $
#
# PDFlib client: block processing example in C
#

use pdflib_pl 5.0;

$infile = "boilerplate.pdf";
# This is where font/image/PDF input files live. Adjust as necessary.
#
# Note that this directory must also contain the LuciduxSans font outline
# and metrics files.
#
$searchpath = "../data";

%data = (   "name"			=> "Victor Kraxi",
	    "business.title"		=> "Chief Paper Officer",
	    "business.address.line1" 	=> "17, Aviation Road",
	    "business.address.city"	=> "Paperfield",
	    "business.telephone.voice"	=> "phone +1 234 567-89",
	    "business.telephone.fax"	=> "fax +1 234 567-98",
	    "business.email"		=> "victor\@kraxi.com",
	    "business.homepage"		=> "www.kraxi.com"
	);

# create a new PDFlib object
$p = PDF_new();

eval {
    # open new PDF file
    if (PDF_open_file($p, "businesscard.pdf") == -1){
	print "Error: cannot open PDF file businesscard.pdf." ;
	exit;
    }

    PDF_set_parameter($p, "SearchPath", $searchpath);

    PDF_set_info($p, "Creator", "businesscard.pl");
    PDF_set_info($p, "Author", "Thomas Merz");
    PDF_set_info($p, "Title", "PDFlib block processing sample (Perl)");

    $blockcontainer = PDF_open_pdi($p, $infile, "", 0);
    if ($blockcontainer == -1){
	die "Couldn't open input file $infile.\n";
    }

    $page = PDF_open_pdi_page($p, $blockcontainer, 1, "");
    if ($page == -1){
	die "Couldn't open page 1 in $infile.\n";
    }

    PDF_begin_page($p, 20, 20);		# dummy page size

    # This will adjust the page size to the block container's size.
    PDF_fit_pdi_page($p, $page, 0, 0, "adjustpage");

    # Fill all text blocks with dynamic data
    foreach $elem(keys %data){
	if (PDF_fill_textblock($p, $page, $elem, $data{$elem},
            "embedding pdiwarning encoding=winansi") == -1) {
	    printf("Warning: couldn't fill block '%s' in '%s'.\n", $elem,
		$data{$elem});
	}
    }

    PDF_end_page($p);			# close page
    PDF_close_pdi_page($p, $page);

    PDF_close($p);			# close PDF document
    PDF_close_pdi($p, $blockcontainer);
};
if ($@) {
    printf("businesscard: PDFlib Exception occurred:\n");
    printf(" $@\n");
    exit;
}
PDF_delete($p); 			# delete the PDFlib object
